@@ -12,13 +12,13 @@
 #
 ##############################################################################
 
-from Products.PloneTestCase.layer import PloneSiteLayer
-import Products.PloneTestCase.PloneTestCase
+import gocept.httpserverlayer.plonetestcase
 import gocept.selenium.base
-import gocept.selenium.zope2
 
 
 class TestCase(gocept.selenium.base.TestCase,
-               Products.PloneTestCase.PloneTestCase.FunctionalTestCase):
-
-    layer = gocept.selenium.zope2.Layer(PloneSiteLayer)
+               gocept.httpserverlayer.plonetestcase.TestCase):
+    """NOTE: MRO requires gocept.selenium.base.TestCase to come first,
+    otherwise its setUp/tearDown is never called, since unittest.TestCase
+    does not call super().
+    """
