@@ -15,13 +15,19 @@
 from gocept.selenium.selenese import camelcase_to_underscore
 from gocept.selenium.selenese import selenese_pattern_equals as match
 import glob
+import gocept.selenium
 import gocept.selenium.selenese
 import gocept.selenium.static
 import os
 import pkg_resources
+import random
 import shutil
 import time
-import unittest
+
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 
 
 class PatternTest(unittest.TestCase):
@@ -81,7 +87,7 @@ class NonexistentNameTest(unittest.TestCase):
             def get_with_wrong_assert_type(self):
                 pass
 
-        self.selenese = Selenese(None, None, None)
+        self.selenese = Selenese(None, None)
 
     def assertError(self, error, name, expected_msg):
         try:
@@ -117,7 +123,7 @@ class NonexistentNameTest(unittest.TestCase):
                          "selenese method 'assert_with_wrong_assert_type'.")
 
 
-class HTMLTestCase(gocept.selenium.static.TestCase):
+class HTMLTestCase(gocept.selenium.static.TestCase, unittest.TestCase):
 
     def setUp(self):
         super(HTMLTestCase, self).setUp()
@@ -185,12 +191,14 @@ class AssertionTest(HTMLTestCase):
         self.selenium.open('/')
         self.selenium.verifyAlertNotPresent()
 
+    @gocept.selenium.skipUnlessBrowser('Firefox', '>=16.0')
     def test_alert_present(self):
         self.selenium.open('/alert.html')
         time.sleep(0.6)
         self.selenium.verifyAlertPresent()
         self.selenium.getAlert()
 
+    @gocept.selenium.skipUnlessBrowser('Firefox', '>=16.0')
     def test_wait_for_alert(self):
         self.selenium.open('/alert.html')
         self.selenium.verifyAlertNotPresent()
@@ -222,57 +230,67 @@ class AssertionTest(HTMLTestCase):
             self.fail('Did not raise an exception')
 
 
+popup_test_count = 0
+
+
 class PopUpTest(HTMLTestCase):
 
     def setUp(self):
+        global popup_test_count
+        popup_test_count += 1
         super(PopUpTest, self).setUp()
-        self.selenium.open('/launch-popup.html')
 
     def tearDown(self):
         try:
-            self.selenium.selectPopUp(wait=False)
+            self.selenium.selectPopUp(self.popup_id, wait=False)
         except Exception:
             pass
-        if self.selenium.getLocation().endswith('/popup.html'):
+        else:
             self.selenium.close()
             self.selenium.deselectPopUp()
         self.selenium.setTimeout(30)
         super(PopUpTest, self).tearDown()
 
-    def test_wait_for_and_select_popup(self):
-        # smoke tests for calls not otherwise used in this test class
-        self.selenium.waitForPopUp('gocept.selenium-popup')
-        self.selenium.waitForPopUp()
-        self.selenium.selectPopUp()
+    def open_popup(self):
+        self.popup_id = 'gocept.selenium-popup%s' % popup_test_count
+        self.selenium.open('/launch-popup.html?%s' % self.popup_id)
 
+    @gocept.selenium.skipUnlessBrowser('Firefox', '>=16.0')
     def test_wait_for_popup_times_out(self):
-        self.selenium.selectPopUp('gocept.selenium-popup')
+        self.open_popup()
+        self.selenium.selectPopUp(self.popup_id)
         self.selenium.close()
         self.selenium.deselectPopUp()
         self.selenium.setTimeout(0)
         self.assertRaises(Exception, self.selenium.waitForPopUp,
-                          'gocept.selenium-popup')
+                          self.popup_id)
         self.assertRaises(Exception, self.selenium.waitForPopUp)
         self.selenium.setTimeout(1)
         self.assertRaises(Exception, self.selenium.waitForPopUp,
-                          'gocept.selenium-popup')
+                          self.popup_id)
         self.assertRaises(Exception, self.selenium.waitForPopUp)
 
+    @gocept.selenium.skipUnlessBrowser('Firefox', '>=16.0')
     def test_select_popup(self):
+        self.open_popup()
         self.assertRaises(Exception,
                           self.selenium.selectPopUp,
-                          'gocept.selenium-popup', wait=False)
-        self.selenium.selectPopUp('gocept.selenium-popup')
+                          self.popup_id, wait=False)
+        self.selenium.selectPopUp(self.popup_id)
         self.selenium.verifyElementPresent('css=div#popup')
 
+    @gocept.selenium.skipUnlessBrowser('Firefox', '>=16.0')
     def test_deselect_popup(self):
-        self.selenium.selectPopUp('gocept.selenium-popup')
+        self.open_popup()
+        self.selenium.selectPopUp(self.popup_id)
         self.selenium.deselectPopUp()
         self.selenium.verifyElementNotPresent('css=div#popup')
         self.selenium.verifyElementPresent('css=div#parent')
 
+    @gocept.selenium.skipUnlessBrowser('Firefox', '>=16.0')
     def test_close(self):
-        self.selenium.selectPopUp('gocept.selenium-popup')
+        self.open_popup()
+        self.selenium.selectPopUp(self.popup_id)
         self.selenium.verifyElementPresent('css=div#popup')
         self.selenium.close()
         self.assertRaises(Exception,
